==> flutter_conscent_plugin-0.1.1.tar.gz: lib/View/webview.dart <==
import 'dart:convert';
import 'package:flutter_conscent_plugin/ConscentInitializer.dart';
import 'package:flutter_conscent_plugin/defaultSubscribtion.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';

import 'Model/APIMode.dart';
//import 'package:flutter_new/defaultSubscribtion.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewApp(),
    ),
  );
}

class WebViewApp extends StatefulWidget {
  const WebViewApp({super.key});

  @override
  State<WebViewApp> createState() => _WebViewAppState();
}

class _WebViewAppState extends State<WebViewApp> {
  String? loginId;
  // String? sessionId;

  bool showContent = false;
  bool isLoaded = false;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();
  // final sessionId = TextEditingController();

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

  dynamic dataMain;
  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    print(loginId.toString());
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    print('getSessionId------');
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    print(uri);
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      dataMain = jsonDecode(response.body);
      final prefs = await SharedPreferences.getInstance();
      print('dev sessionnnnnnnnnnnnn id');
      print(prefs.getString('sessionId'));
      String sessionId = dataMain['sessionId'].toString();
      prefs.setString('sessionId', sessionId);
      print("dataMain");
      print(dataMain);
      print("dataMain");
      CircularProgressIndicator();
      return sessionId;
      // Navigator.pop(context,{
      //   "sessionId":dataMain['sessionId']
      // });
    }
    return '';
  }

  dynamic dataMains;
  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    print('sessionId xyz= $sessionId');
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": '${ConscentInitializer.mClientId}',
      "clientContentId": '${ConscentInitializer.mContentId}',
      "sessionId": sessionId,
    });
    print('-------------------------------------------------------');
    print('${response.body}---- status---${response.statusCode}');

    if (response.statusCode == 201) {
      dataMains = jsonDecode(response.body);
      var responseString = response.body;

      Navigator.pop(context, {"response": responseString});
    }
  }

  JavascriptChannel _javascriptChannel() {
    print('javascript');
    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          print(message.message);
          if (message.message == 'loginSuccess') {
            CircularProgressIndicator();
            print('javascript----------');
            String sessionId = await getSessionID(loginId!);
            submitDatas('${ConscentInitializer.mClientId}',
                '${ConscentInitializer.mContentId}', sessionId);
          }
        });
  }

  // Home

  Widget homeBody() {
    return !isLoaded
        ? const CircularProgressIndicator()
        : Padding(
            padding: const EdgeInsets.all(8.0),
          );
  }

  //home

  // ... to here.

  @override
  Widget build(BuildContext context) {
    javascriptChannels:
    <JavascriptChannel>{_javascriptChannel()};
    // getLoginChallengeId();
    var flutterWebViewPlugin;
    print(loginId);
    print(sessionId);
    print('kunallllllll');

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl:
                  '${APIMode.SERVICE_BASE_URL}/overlay?clientId=${ConscentInitializer.mClientId}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId',
              javascriptMode: JavascriptMode.unrestricted,
              onProgress: (int progress) async {
                javascriptChannels:
                <JavascriptChannel>{_javascriptChannel()};
                print('WebView is loading (progress : $progress%)');
              },
              onWebViewCreated: (controller) {
                print('---onWebViewCreated----${controller.currentUrl()}');
              },
              navigationDelegate: (NavigationRequest request) {
                print('----navigation delegate---${request.url}');

                if (request.url.startsWith('https://xyz.zyz')) {
                  print('APIU CALL FIRST');

                  getSessionID(loginId!);

                  return NavigationDecision.prevent;
                } else if (request.url.startsWith(
                    '${APIMode.SERVICE_BASE_URL}/?csc-tierId=619b7f6cfbacc96bd8fb232a')) {
                  Navigator.pop(context);
                }

                print('allowing navigation to $request');
                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {
                print('Page started loading: $url');
              },
              onPageFinished: (String url) {
                print('Page finished loading: $url');
                print('urllllllllllllllllllll: $url');
              },
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : Center(child: CircularProgressIndicator()),
    );
  }
}

==> flutter_conscent_plugin-0.1.2.tar.gz: lib/View/webview.dart <==
import 'dart:convert';
import 'package:flutter_conscent_plugin/View/defaultSubscribtion.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';

import '../Model/APIMode.dart';
import 'ConscentInitializer.dart';

//import 'package:flutter_new/defaultSubscribtion.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewApp(),
    ),
  );
}

class WebViewApp extends StatefulWidget {
  const WebViewApp({super.key});

  @override
  State<WebViewApp> createState() => _WebViewAppState();
}

class _WebViewAppState extends State<WebViewApp> {
  String? loginId;
  // String? sessionId;

  bool showContent = false;
  bool isLoaded = false;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();
  // final sessionId = TextEditingController();

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

  dynamic dataMain;
  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    print(loginId.toString());
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    print('getSessionId------');
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    print(uri);
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      dataMain = jsonDecode(response.body);
      final prefs = await SharedPreferences.getInstance();
      print('dev sessionnnnnnnnnnnnn id');
      print(prefs.getString('sessionId'));
      String sessionId = dataMain['sessionId'].toString();
      prefs.setString('sessionId', sessionId);
      print("dataMain");
      print(dataMain);
      print("dataMain");
      CircularProgressIndicator();
      return sessionId;
      // Navigator.pop(context,{
      //   "sessionId":dataMain['sessionId']
      // });
    }
    return '';
  }

  dynamic dataMains;
  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    print('sessionId xyz= $sessionId');
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": '${ConscentInitializer.mClientId}',
      "clientContentId": '${ConscentInitializer.mContentId}',
      "sessionId": sessionId,
    });
    print('-------------------------------------------------------');
    print('${response.body}---- status---${response.statusCode}');

    if (response.statusCode == 201) {
      dataMains = jsonDecode(response.body);
      var responseString = response.body;

      Navigator.pop(context, {"response": responseString});
    }
  }

  JavascriptChannel _javascriptChannel() {
    print('javascript');
    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          print(message.message);
          if (message.message == 'loginSuccess') {
            CircularProgressIndicator();
            print('javascript----------');
            String sessionId = await getSessionID(loginId!);
            submitDatas('${ConscentInitializer.mClientId}',
                '${ConscentInitializer.mContentId}', sessionId);
          }
        });
  }

  // Home

  Widget homeBody() {
    return !isLoaded
        ? const CircularProgressIndicator()
        : Padding(
            padding: const EdgeInsets.all(8.0),
          );
  }

  //home

  // ... to here.

  @override
  Widget build(BuildContext context) {
    javascriptChannels:
    <JavascriptChannel>{_javascriptChannel()};
    // getLoginChallengeId();
    var flutterWebViewPlugin;
    print(loginId);
    print(sessionId);
    print('kunallllllll');

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl:
                  '${APIMode.SERVICE_BASE_URL}/overlay?clientId=${ConscentInitializer.mClientId}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId',
              javascriptMode: JavascriptMode.unrestricted,
              onProgress: (int progress) async {
                javascriptChannels:
                <JavascriptChannel>{_javascriptChannel()};
                print('WebView is loading (progress : $progress%)');
              },
              onWebViewCreated: (controller) {
                print('---onWebViewCreated----${controller.currentUrl()}');
              },
              navigationDelegate: (NavigationRequest request) {
                print('----navigation delegate---${request.url}');

                if (request.url.startsWith('https://xyz.zyz')) {
                  print('APIU CALL FIRST');

                  getSessionID(loginId!);

                  return NavigationDecision.prevent;
                } else if (request.url.startsWith(
                    '${APIMode.SERVICE_BASE_URL}/?csc-tierId=619b7f6cfbacc96bd8fb232a')) {
                  Navigator.pop(context);
                }

                print('allowing navigation to $request');
                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {
                print('Page started loading: $url');
              },
              onPageFinished: (String url) {
                print('Page finished loading: $url');
                print('urllllllllllllllllllll: $url');
              },
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : Center(child: CircularProgressIndicator()),
    );
  }
}
